@@ -24,6 +24,7 @@ import org.neptuneinc.cadstat.utils.RUtils;
 import org.rosuda.JGR.JGR;
 import org.rosuda.REngine.REXPMismatchException;
 import org.rosuda.REngine.REngineException;
+import CADStat.java.plots.SubsetFormatter;
 
 /**
  *
@@ -747,11 +748,11 @@ private void independentListValueChanged(javax.swing.event.ListSelectionEvent ev
     String cmd = "glm.pred.JGR("
       + "my.data=" + this.getDatasetPane().getSelectedDataset()
       + ", subset1.name=" + (this.getFactorSelectionPane1().getFactorValueList().isSelectionEmpty() ? "NULL" : "'" + this.getFactorSelectionPane1().getSelectedFactor() + "'")
-      + ", subset1.val=" + (this.getFactorSelectionPane1().getFactorValueList().isSelectionEmpty() ? "NULL" : "c(" + RUtils.toString(this.getFactorSelectionPane1().getSelectedFactorValues(), ",", "'") + ")")
+      + ", subset1.val=" + (this.getFactorSelectionPane1().getFactorValueList().isSelectionEmpty() ? "NULL" : SubsetFormatter.formatSubset(this.getFactorSelectionPane1().getSelectedFactorValues()))
       + ", subset2.name=" + (this.getFactorSelectionPane2().getFactorValueList().isSelectionEmpty() ? "NULL" : "'" + this.getFactorSelectionPane2().getSelectedFactor() + "'")
-      + ", subset2.val=" + (this.getFactorSelectionPane2().getFactorValueList().isSelectionEmpty() ? "NULL" : "c(" + RUtils.toString(this.getFactorSelectionPane2().getSelectedFactorValues(), ",", "'") + ")")
+      + ", subset2.val=" + (this.getFactorSelectionPane2().getFactorValueList().isSelectionEmpty() ? "NULL" : SubsetFormatter.formatSubset(this.getFactorSelectionPane2().getSelectedFactorValues()))
       + ", site.name=" + "'" + getSiteVarList().getSelectedItem().toString() + "'"
-      + ", site.val=" + "c(" + RUtils.toString(getSiteValListSelectedValues(), ",", "'") + ")"
+      + ", site.val=" + SubsetFormatter.formatSubset(getSiteValListSelectedValues())
       + ", my.formula=" + "'" + this.getModelString() + "'"
       + ", my.family=" + "'" + distfamily + "'"
       + ", label.name=" + "'" + idVarList.getSelectedItem() + "'"
